@@ -655,16 +655,16 @@ def get_predictions(all_examples, all_features, all_results, n_best_size,
     assert len(nbest_json) >= 1
 
     if not FLAGS.version_2_with_negative:
-      all_predictions[example.qas_id] = nbest_json[0]["text"]
+      all_predictions[example.qas_id] = (nbest_json[0]["text"], nbest_json[0]["start_logit"]+nbest_json[0]["end_logit"])
     else:
       # predict "" iff the null score - the score of best non-null > threshold
       score_diff = score_null - best_non_null_entry.start_logit - (
           best_non_null_entry.end_logit)
       scores_diff_json[example.qas_id] = score_diff
       if score_diff > FLAGS.null_score_diff_threshold:
-        all_predictions[example.qas_id] = ""
+        all_predictions[example.qas_id] = ("", 0)
       else:
-        all_predictions[example.qas_id] = best_non_null_entry.text
+        all_predictions[example.qas_id] = (best_non_null_entry.text, best_non_null_entry.start_logit+best_non_null_entry.end_logit)
 
   return all_predictions
 
